# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _


class Country(models.Model):
    """
    International Organization for Standardization (ISO) 3166-1 Country list
    """
    iso2_code = models.CharField(
        max_length=2,
        primary_key=True,
        verbose_name=_('ISO alpha-2'),
    )
    name = models.CharField(
        max_length=128,
        db_index=True,
        verbose_name=_('official name (CAPS)'),
    )
    printable_name = models.CharField(
        max_length=128,
        db_index=True,
        verbose_name=_('country name'),
    )
    iso3_code = models.CharField(
        max_length=3,
        unique=True,
        verbose_name=_('ISO alpha-3'),
    )
    numcode = models.PositiveSmallIntegerField(
        null=True,
        blank=True,
        verbose_name=_('ISO numeric'),
    )
    active = models.BooleanField(
        default=True,
        verbose_name=_('country is active'),
    )
    continent = models.CharField(
        choices=settings.L10N_CONTINENTS,
        max_length=2,
        verbose_name=_('continent'),
    )
    admin_area = models.CharField(
        choices=settings.L10N_AREAS,
        max_length=2,
        blank=True,
        db_index=True,
        verbose_name=_('administrative area'),
    )

    class Meta:
        verbose_name = _('country')
        verbose_name_plural = _('countries')
        ordering = ('name',)

    def __unicode__(self):
        return self.printable_name


class AdministrativeArea(models.Model):
    """
    Administrative Area level 1 for a country.  For the US, this would be the states
    """
    country = models.ForeignKey(
        Country,
        related_name='administrative_areas',
        verbose_name=_("country")
    )
    name = models.CharField(
        max_length=60,
        db_index=True,
        verbose_name=_('admin area name'),
    )
    abbrev = models.CharField(
        max_length=3,
        blank=True,
        verbose_name=_('postal abbreviation'),
    )
    active = models.BooleanField(
        default=True,
        verbose_name=_('area is active'),
    )

    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name = _('administrative area')
        verbose_name_plural = _('administrative areas')
        ordering = ('name',)
